==> rce-10.2.4-release-source.zip: de.rcenvironment.core.gui.wizards.toolintegration/src/main/java/de/rcenvironment/core/gui/wizards/toolintegration/Messages.java <==
/*
 * Copyright 2006-2021 DLR, Germany
 * 
 * SPDX-License-Identifier: EPL-1.0
 * 
 * https://rcenvironment.de/
 */

package de.rcenvironment.core.gui.wizards.toolintegration;

import org.eclipse.osgi.util.NLS;

/**
 * Supports language specific messages.
 * 
 * @author Sascha Zur
 */
public class Messages extends NLS {

    /** NLS Constant. */
    public static String wizardTitle;

    /** NLS Constant. */
    public static String firstToolIntegrationPageTitle;

    /** NLS Constant. */
    public static String firstPageDescription;

    /** NLS Constant. */
    public static String toolPropGroup;

    /** NLS Constant. */
    public static String inOuputPage;

    /** NLS Constant. */
    public static String nameRequired;

    /** NLS Constant. */
    public static String dataType;

    /** NLS Constant. */
    public static String dataTypeColon;

    /** NLS Constant. */
    public static String dataTypes;

    /** NLS Constant. */
    public static String edit;

    /** NLS Constant. */
    public static String add;

    /** NLS Constant. */
    public static String remove;

    /** NLS Constant. */
    public static String propertyPage;

    /** NLS Constant. */
    public static String toolPage;

    /** NLS Constant. */
    public static String scriptPage;

    /** NLS Constant. */
    public static String iconPath;

    /** NLS Constant. */
    public static String toolDescription;

    /** NLS Constant. */
    public static String userInformationGroup;

    /** NLS Constant. */
    public static String email;

    /** NLS Constant. */
    public static String toolIntegrationWizardDescription;

    /** NLS Constant. */
    public static String inoutputPageDescription;

    /** NLS Constant. */
    public static String inputHandling;

    /** NLS Constant. */
    public static String inputExecutionConstraint;

    /** NLS Constant. */
    public static String inputHandlingColon;
    
    /** NLS Constant. */
    public static String defaultInputHandlingColon;

    /** NLS Constant. */
    public static String inputExecutionConstraintColon;

    /** NLS Constant. */
    public static String defaultInputExecutionConstraintColon;
    
    /** NLS Constant. */
    public static String folder;

    /** NLS Constant. */
    public static String filename;

    /** NLS Constant. */
    public static String filenameColon;

    /** NLS Constant. */
    public static String displayNameColon;

    /** NLS Constant. */
    public static String keyColon;

    /** NLS Constant. */
    public static String defaultValueColon;

    /** NLS Constant. */
    public static String displayName;

    /** NLS Constant. */
    public static String type;

    /** NLS Constant. */
    public static String key;

    /** NLS Constant. */
    public static String defaultValue;

    /** NLS Constant. */
    public static String properties;

    /** NLS Constant. */
    public static String host;

    /** NLS Constant. */
    public static String toolDirectory;

    /** NLS Constant. */
    public static String version;

    /** NLS Constant. */
    public static String toolDirectoryColon;

    /** NLS Constant. */
    public static String versionColon;

    /** NLS Constant. */
    public static String toolDirectoryRequired;

    /** NLS Constant. */
    public static String versionRequired;

    /** NLS Constant. */
    public static String rootWorkingDir;

    /** NLS Constant. */
    public static String useIterationDirectoriesText;

    /** NLS Constant. */
    public static String isSandboxToolText;

    /** NLS Constant. */
    public static String deleteWorkingDirectoriesText;

    /** NLS Constant. */
    public static String localHostButtonText;

    /** NLS Constant. */
    public static String hostButtonText;

    /** NLS Constant. */
    public static String port;

    /** NLS Constant. */
    public static String rceTempUsed;
    
    /** NLS Constant. */
    public static String addDiaglogTitle;
    
    /** NLS Constant. */
    public static String editDiaglogTitle;

    /** NLS Constant. */
    public static String inputs;

    /** NLS Constant. */
    public static String outputs;

    /** NLS Constant. */
    public static String commandScriptMessage;

    /** NLS Constant. */
    public static String preScript;

    /** NLS Constant. */
    public static String postScript;

    /** NLS Constant. */
    public static String insertButtonLabel;

    /** NLS Constant. */
    public static String scriptPageDescription;

    /** NLS Constant. */
    public static String toolConfigPageDescription;

    /** NLS Constant. */
    public static String propertyPageDescription;

    /** NLS Constant. */
    public static String createConfigFileButton;

    /** NLS Constant. */
    public static String configFilenameInvalid;

    /** NLS Constant. */
    public static String propTabNameInvalid;

    /** NLS Constant. */
    public static String propTabNameEmpty;

    /** NLS Constant. */
    public static String toolExecutionConfigurationNeeded;

    /** NLS Constant. */
    public static String toolExecutionCommandNeeded;

    /** NLS Constant. */
    public static String toolFilenameInvalid;

    /** NLS Constant. */
    public static String toolFilenameUsed;

    /** NLS Constant. */
    public static String useCustomTempDir;

    /** NLS Constant. */
    public static String directory;

    /** NLS Constant. */
    public static String groupConfigHeader;

    /** NLS Constant. */
    public static String noConfigGroupSelected;

    /** NLS Constant. */
    public static String configGroupsHeader;

    /** NLS Constant. */
    public static String newGroupName;

    /** NLS Constant. */
    public static String copyGroupTitle;

    /** NLS Constant. */
    public static String deleteGroupTitle;

    /** NLS Constant. */
    public static String copyNever;

    /** NLS Constant. */
    public static String copyOnce;

    /** NLS Constant. */
    public static String copyAlways;

    /** NLS Constant. */
    public static String deleteNever;

    /** NLS Constant. */
    public static String deleteOnce;

    /** NLS Constant. */
    public static String deleteAlways;

    /** NLS Constant. */
    public static String scriptLanguageHint;

    /** NLS Constant. */
    public static String winCommandUse;

    /** NLS Constant. */
    public static String linuxCommandUse;

    /** NLS Constant. */
    public static String emptyFilename;

    /** NLS Constant. */
    public static String emptyFilenameTable;

    /** NLS Constant. */
    public static String fieldRequired;

    /** NLS Constant. */
    public static String nameIntegrator;

    /** NLS Constant. */
    public static String property;

    /** NLS Constant. */
    public static String configuration;

    /** NLS Constant. */
    public static String saveAsLabel;

    /** NLS Constant. */
    public static String integrateLabel;

    /** NLS Constant. */
    public static String groupNameText;

    /** NLS Constant. */
    public static String updateLabel;

    /** NLS Constant. */
    public static String tempDirBehaviourNeeded;

    /** NLS Constant. */
    public static String rename;

    /** NLS Constant. */
    public static String value;

    /** NLS Constant. */
    public static String propertyConfiguration;

    /** NLS Constant. */
    public static String propGroupsLabel;

    /** NLS Constant. */
    public static String name;

    /** NLS Constant. */
    public static String newIntegrationDescription;

    /** NLS Constant. */
    public static String editIntegrationDescription;

    /** NLS Constant. */
    public static String newConfigurationButton;

    /** NLS Constant. */
    public static String chooseInactiveButton;

    /** NLS Constant. */
    public static String chooseConfigToEdit;

    /** NLS Constant. */
    public static String loadConfigurationButton;

    /** NLS Constant. */
    public static String selectedConfig;

    /** NLS Constant. */
    public static String iconSizeMessage;

    /** NLS Constant. */
    public static String publishComponentCheckbox;

    /** NLS Constant. */
    public static String chooseConfigPageTitle;

    /** NLS Constant. */
    public static String dontCrashOtherThanZeroLabel;

    /** NLS Constant. */
    public static String exitCodeLabel;

    /** NLS Constant. */
    public static String integrateToolJobTitle;

    /** NLS Constant. */
    public static String scriptLanguageHintBatch;

    /** NLS Constant. */
    public static String scriptLanguageHintBash;

    /** NLS Constant. */
    public static String deleteToolNote;

    /** NLS Constant. */
    public static String newConfigurationFromTemplateButton;

    /** NLS Constant. */
    public static String chooseGroupDlgTitle;

    /** NLS Constant. */
    public static String chooseGroupDlgMessage;

    /** NLS Constant. */
    public static String copyIconButtonLabel;

    /** NLS Constant. */
    public static String limitExecutionInstances;

    /** NLS Constant. */
    public static String deleteNotOnErrorIteration;

    /** NLS Constant. */
    public static String deleteNotOnErrorOnce;

    /** NLS Constant. */
    public static String copyDialogShellText;

    /** NLS Constant. */
    public static String copy;

    /** NLS Constant. */
    public static String customPath;

    /** NLS Constant. */
    public static String copyFileToFile;

    /** NLS Constant. */
    public static String copyFileToDir;

    /** NLS Constant. */
    public static String copyDirToDir;

    /** NLS Constant. */
    public static String insertCommand;

    /** NLS Constant. */
    public static String source;

    /** NLS Constant. */
    public static String target;

    /** NLS Constant. */
    public static String predefinedPath;

    /** NLS Constant. */
    public static String subfolderOrFilename;

    private static final String BUNDLE_NAME = Messages.class.getPackage().getName() + ".messages";

    static {
        // initialize resource bundle
        NLS.initializeMessages(BUNDLE_NAME, Messages.class);
    }
}

==> rce-10.3.0-release-source.zip: de.rcenvironment.core.gui.wizards.toolintegration/src/main/java/de/rcenvironment/core/gui/wizards/toolintegration/Messages.java <==
/*
 * Copyright 2006-2021 DLR, Germany
 * 
 * SPDX-License-Identifier: EPL-1.0
 * 
 * https://rcenvironment.de/
 */

package de.rcenvironment.core.gui.wizards.toolintegration;

import org.eclipse.osgi.util.NLS;

/**
 * Supports language specific messages.
 * 
 * @author Sascha Zur
 */
public class Messages extends NLS {

    /** NLS Constant. */
    public static String wizardTitle;

    /** NLS Constant. */
    public static String firstToolIntegrationPageTitle;

    /** NLS Constant. */
    public static String firstPageDescription;

    /** NLS Constant. */
    public static String toolPropGroup;

    /** NLS Constant. */
    public static String inOuputPage;

    /** NLS Constant. */
    public static String nameRequired;

    /** NLS Constant. */
    public static String dataType;

    /** NLS Constant. */
    public static String dataTypeColon;

    /** NLS Constant. */
    public static String dataTypes;

    /** NLS Constant. */
    public static String edit;

    /** NLS Constant. */
    public static String add;

    /** NLS Constant. */
    public static String remove;

    /** NLS Constant. */
    public static String propertyPage;

    /** NLS Constant. */
    public static String toolPage;

    /** NLS Constant. */
    public static String scriptPage;

    /** NLS Constant. */
    public static String iconPath;

    /** NLS Constant. */
    public static String toolDescription;

    /** NLS Constant. */
    public static String userInformationGroup;

    /** NLS Constant. */
    public static String email;

    /** NLS Constant. */
    public static String toolIntegrationWizardDescription;

    /** NLS Constant. */
    public static String inoutputPageDescription;

    /** NLS Constant. */
    public static String inputHandling;

    /** NLS Constant. */
    public static String inputExecutionConstraint;

    /** NLS Constant. */
    public static String inputHandlingColon;
    
    /** NLS Constant. */
    public static String defaultInputHandlingColon;

    /** NLS Constant. */
    public static String inputExecutionConstraintColon;

    /** NLS Constant. */
    public static String defaultInputExecutionConstraintColon;
    
    /** NLS Constant. */
    public static String folder;

    /** NLS Constant. */
    public static String filename;

    /** NLS Constant. */
    public static String filenameColon;

    /** NLS Constant. */
    public static String displayNameColon;

    /** NLS Constant. */
    public static String keyColon;

    /** NLS Constant. */
    public static String defaultValueColon;

    /** NLS Constant. */
    public static String commentColon;

    /** NLS Constant. */
    public static String displayName;

    /** NLS Constant. */
    public static String type;

    /** NLS Constant. */
    public static String key;

    /** NLS Constant. */
    public static String defaultValue;

    /** NLS Constant. */
    public static String properties;

    /** NLS Constant. */
    public static String host;

    /** NLS Constant. */
    public static String toolDirectory;

    /** NLS Constant. */
    public static String version;

    /** NLS Constant. */
    public static String toolDirectoryColon;

    /** NLS Constant. */
    public static String versionColon;

    /** NLS Constant. */
    public static String toolDirectoryRequired;

    /** NLS Constant. */
    public static String versionRequired;

    /** NLS Constant. */
    public static String rootWorkingDir;

    /** NLS Constant. */
    public static String useIterationDirectoriesText;

    /** NLS Constant. */
    public static String isSandboxToolText;

    /** NLS Constant. */
    public static String deleteWorkingDirectoriesText;

    /** NLS Constant. */
    public static String localHostButtonText;

    /** NLS Constant. */
    public static String hostButtonText;

    /** NLS Constant. */
    public static String port;

    /** NLS Constant. */
    public static String rceTempUsed;
    
    /** NLS Constant. */
    public static String addDiaglogTitle;
    
    /** NLS Constant. */
    public static String editDiaglogTitle;

    /** NLS Constant. */
    public static String inputs;

    /** NLS Constant. */
    public static String outputs;

    /** NLS Constant. */
    public static String commandScriptMessage;

    /** NLS Constant. */
    public static String preScript;

    /** NLS Constant. */
    public static String postScript;

    /** NLS Constant. */
    public static String insertButtonLabel;

    /** NLS Constant. */
    public static String scriptPageDescription;

    /** NLS Constant. */
    public static String toolConfigPageDescription;

    /** NLS Constant. */
    public static String propertyPageDescription;

    /** NLS Constant. */
    public static String createConfigFileButton;

    /** NLS Constant. */
    public static String configFilenameInvalid;

    /** NLS Constant. */
    public static String propTabNameInvalid;

    /** NLS Constant. */
    public static String propTabNameEmpty;

    /** NLS Constant. */
    public static String toolExecutionConfigurationNeeded;

    /** NLS Constant. */
    public static String toolExecutionCommandNeeded;

    /** NLS Constant. */
    public static String toolFilenameInvalid;

    /** NLS Constant. */
    public static String toolFilenameUsed;

    /** NLS Constant. */
    public static String useCustomTempDir;

    /** NLS Constant. */
    public static String directory;

    /** NLS Constant. */
    public static String groupConfigHeader;

    /** NLS Constant. */
    public static String noConfigGroupSelected;

    /** NLS Constant. */
    public static String configGroupsHeader;

    /** NLS Constant. */
    public static String newGroupName;

    /** NLS Constant. */
    public static String copyGroupTitle;

    /** NLS Constant. */
    public static String deleteGroupTitle;

    /** NLS Constant. */
    public static String copyNever;

    /** NLS Constant. */
    public static String copyOnce;

    /** NLS Constant. */
    public static String copyAlways;

    /** NLS Constant. */
    public static String deleteNever;

    /** NLS Constant. */
    public static String deleteOnce;

    /** NLS Constant. */
    public static String deleteAlways;

    /** NLS Constant. */
    public static String scriptLanguageHint;

    /** NLS Constant. */
    public static String winCommandUse;

    /** NLS Constant. */
    public static String linuxCommandUse;

    /** NLS Constant. */
    public static String emptyFilename;

    /** NLS Constant. */
    public static String emptyFilenameTable;

    /** NLS Constant. */
    public static String fieldRequired;

    /** NLS Constant. */
    public static String nameIntegrator;

    /** NLS Constant. */
    public static String addProperty;

    /** NLS Constant. */
    public static String editProperty;

    /** NLS Constant. */
    public static String configuration;

    /** NLS Constant. */
    public static String saveAsLabel;

    /** NLS Constant. */
    public static String integrateLabel;

    /** NLS Constant. */
    public static String groupPathText;

    /** NLS Constant. */
    public static String updateLabel;

    /** NLS Constant. */
    public static String tempDirBehaviourNeeded;

    /** NLS Constant. */
    public static String rename;

    /** NLS Constant. */
    public static String value;

    /** NLS Constant. */
    public static String propertyConfiguration;

    /** NLS Constant. */
    public static String propGroupsLabel;

    /** NLS Constant. */
    public static String name;

    /** NLS Constant. */
    public static String newIntegrationDescription;

    /** NLS Constant. */
    public static String editIntegrationDescription;

    /** NLS Constant. */
    public static String newConfigurationButton;

    /** NLS Constant. */
    public static String chooseInactiveButton;

    /** NLS Constant. */
    public static String chooseConfigToEdit;

    /** NLS Constant. */
    public static String loadConfigurationButton;

    /** NLS Constant. */
    public static String selectedConfig;

    /** NLS Constant. */
    public static String iconSizeMessage;

    /** NLS Constant. */
    public static String publishComponentCheckbox;

    /** NLS Constant. */
    public static String chooseConfigPageTitle;

    /** NLS Constant. */
    public static String dontCrashOtherThanZeroLabel;

    /** NLS Constant. */
    public static String exitCodeLabel;

    /** NLS Constant. */
    public static String integrateToolJobTitle;

    /** NLS Constant. */
    public static String scriptLanguageHintBatch;

    /** NLS Constant. */
    public static String scriptLanguageHintBash;

    /** NLS Constant. */
    public static String deleteToolNote;

    /** NLS Constant. */
    public static String newConfigurationFromTemplateButton;

    /** NLS Constant. */
    public static String chooseGroupDlgTitle;

    /** NLS Constant. */
    public static String chooseGroupDlgMessage;

    /** NLS Constant. */
    public static String copyIconButtonLabel;

    /** NLS Constant. */
    public static String limitExecutionInstances;

    /** NLS Constant. */
    public static String deleteNotOnErrorIteration;

    /** NLS Constant. */
    public static String deleteNotOnErrorOnce;

    /** NLS Constant. */
    public static String copyDialogShellText;

    /** NLS Constant. */
    public static String copy;

    /** NLS Constant. */
    public static String customPath;

    /** NLS Constant. */
    public static String copyFileToFile;

    /** NLS Constant. */
    public static String copyFileToDir;

    /** NLS Constant. */
    public static String copyDirToDir;

    /** NLS Constant. */
    public static String insertCommand;

    /** NLS Constant. */
    public static String source;

    /** NLS Constant. */
    public static String target;

    /** NLS Constant. */
    public static String predefinedPath;

    /** NLS Constant. */
    public static String subfolderOrFilename;

    private static final String BUNDLE_NAME = Messages.class.getPackage().getName() + ".messages";

    static {
        // initialize resource bundle
        NLS.initializeMessages(BUNDLE_NAME, Messages.class);
    }
}
